==> massxpert3_10.4.0.orig.tar.gz: massxpert3-10.4.0/src/gui/CrossLinkerDefDlg.hpp <==
/* BEGIN software license
 *
 * MsXpertSuite - mass spectrometry software suite
 * -----------------------------------------------
 * Copyright(C) 2009,...,2026 Filippo Rusconi
 *
 * http://www.msxpertsuite.org
 *
 * This file is part of the MsXpertSuite project.
 *
 * The MsXpertSuite project is the successor of the massXpert project. This
 * project now includes various independent modules:
 *
 * - MassXpert, model polymer chemistries and simulate mass spectrometric data;
 * - MineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * END software license
 */

#pragma once

/////////////////////// stdlib includes


/////////////////////// Qt includes


/////////////////////// pappsomspp includes


/////////////////////// libXpertMass includes
#include <MsXpS/libXpertMassCore/PolChemDef.hpp>


/////////////////////// libXpertMassGui includes


/////////////////////// Local includes
#include "AbstractPolChemDefDependentDlg.hpp"
#include "ui_CrossLinkerDefDlg.h"


namespace MsXpS
{
namespace MassXpert
{


class PolChemDef;
class PolChemDefWnd;
class CrossLinker;
class Modif;


class CrossLinkerDefDlg : public AbstractPolChemDefDependentDlg
{
  Q_OBJECT

  public:
  CrossLinkerDefDlg(libXpertMassCore::PolChemDefSPtr pol_chem_def_sp,
                    PolChemDefWnd *pol_chem_def_wnd_p,
                    const QString &settings_file_path,
                    const QString &application_name,
                    const QString &description);

  ~CrossLinkerDefDlg();

  bool initialize();
  bool populateAvailableModifList();

  void
  updateCrossLinkerIdentityDetails(libXpertMassCore::CrossLinkerSPtr cross_link_sp);
  void updateModifDetails(libXpertMassCore::ModifCstSPtr modif_csp);

  void clearAllDetails();

  public slots:

  // ACTIONS
  void addCrossLinkerPushButtonClicked();
  void removeCrossLinkerPushButtonClicked();
  void moveUpCrossLinkerPushButtonClicked();
  void moveDownCrossLinkerPushButtonClicked();

  void addModifPushButtonClicked();
  void removeModifPushButtonClicked();
  void moveUpModifPushButtonClicked();
  void moveDownModifPushButtonClicked();

  void applyCrossLinkerPushButtonClicked();
  void applyModifPushButtonClicked();

  bool validatePushButtonClicked();

  // VALIDATION
  bool validate();

  // WIDGETRY
  void crossLinkerListWidgetItemSelectionChanged();
  void modifListWidgetItemSelectionChanged();

  private:
  Ui::CrossLinkerDefDlg m_ui;

  std::vector<MsXpS::libXpertMassCore::CrossLinkerSPtr> &mref_crossLinkers;

  void closeEvent(QCloseEvent *event);

  void writeSettings();
  void readSettings();
};


} // namespace MassXpert
} // namespace MsXpS

==> massxpert_6.0.3.orig.tar.gz: massxpert-6.0.3/src/gui/CrossLinkerDefDlg.hpp <==
/* BEGIN software license
 *
 * msXpertSuite - mass spectrometry software suite
 * -----------------------------------------------
 * Copyright(C) 2009,...,2018 Filippo Rusconi
 *
 * http://www.msxpertsuite.org
 *
 * This file is part of the msXpertSuite project.
 *
 * The msXpertSuite project is the successor of the massXpert project. This
 * project now includes various independent modules:
 *
 * - massXpert, model polymer chemistries and simulate mass spectrometric data;
 * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * END software license
 */


#ifndef CROSS_LINKER_DEF_DLG_HPP
#define CROSS_LINKER_DEF_DLG_HPP


/////////////////////// Local includes
#include "AbstractPolChemDefDependentDlg.hpp"
#include "ui_CrossLinkerDefDlg.h"


namespace msxps
{

	namespace massxpert
	{



class PolChemDef;
class PolChemDefWnd;
class CrossLinker;
class Modif;


class CrossLinkerDefDlg : public AbstractPolChemDefDependentDlg
{
  Q_OBJECT

  private:
  Ui::CrossLinkerDefDlg m_ui;

  QList<CrossLinker *> *mp_list;

  void closeEvent(QCloseEvent *event);

  void writeSettings();
  void readSettings();

  public:
  CrossLinkerDefDlg(PolChemDef *polChemDef,
                    PolChemDefWnd *polChemDefWnd,
                    const QString &settingsFilePath);

  ~CrossLinkerDefDlg();

  bool initialize();
  bool populateAvailableModifList();

  void updateCrossLinkerIdentityDetails(CrossLinker *);
  void updateModifDetails(Modif *);

  void clearAllDetails();

  public slots:

  // ACTIONS
  void addCrossLinkerPushButtonClicked();
  void removeCrossLinkerPushButtonClicked();
  void moveUpCrossLinkerPushButtonClicked();
  void moveDownCrossLinkerPushButtonClicked();

  void addModifPushButtonClicked();
  void removeModifPushButtonClicked();
  void moveUpModifPushButtonClicked();
  void moveDownModifPushButtonClicked();

  void applyCrossLinkerPushButtonClicked();
  void applyModifPushButtonClicked();

  bool validatePushButtonClicked();

  // VALIDATION
  bool validate();

  // WIDGETRY
  void crossLinkerListWidgetItemSelectionChanged();
  void modifListWidgetItemSelectionChanged();
};

} // namespace massxpert

} // namespace msxps


#endif // CROSS_LINKER_DEF_DLG_HPP
